@@ -1,14 +1,9 @@
+import inspect
 import typing as tp
 import logging
 import threading
 from .decorators import wraps
 
-__all__ = [
-    'rethrow_as',
-    'silence_excs',
-    'catch_exception',
-    'log_exceptions',
-]
 
 ExcType = tp.Type[Exception]
 T = tp.TypeVar('T')
@@ -43,8 +38,8 @@ class log_exceptions:
     :param severity: a severity level
     :param format_string: a format string with fields:
         - e      : the exception instance itself
-        - args   : arguments with which the function was called, unavailable if context manager
-        - kwargs : arguments with which the function was called, unavailable if context manager
+        - args   : positional arguments with which the function was called, unavailable if context manager
+        - kwargs : keyword arguments with which the function was called, unavailable if context manager
         You can specify additional fields providing the locals_ argument
         Example: "{exc_type} occurred with message {exc_val} with traceback {exc_tb}"
     :param locals_: local variables to add to the format string. args and kwargs will be overwritten
@@ -54,7 +49,9 @@ class log_exceptions:
     """
     __slots__ = ('logger', 'severity', 'format_string', 'locals', 'exc_types')
 
-    def __init__(self, logger, severity=logging.ERROR, format_string='{exc_val}',
+    def __init__(self, logger: logging.Logger,
+                 severity: int = logging.ERROR,
+                 format_string: str = '{e}',
                  locals_: tp.Optional[tp.Dict] = None,
                  exc_types: tp.Optional[tp.Union[ExcType, tp.Sequence[ExcType]]] = None):
         self.logger = logger
@@ -71,33 +68,41 @@ class log_exceptions:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if exc_type is not None:
-            if issubclass(exc_type, self.exc_types):
-                format_dict = {}
-                if self.locals is not None:
-                    format_dict.update(self.locals)
-                format_dict['e'] = exc_val
-                self.logger.log(self.severity, self.format_string.format(format_dict),
-                                exc_info=exc_val)
+            self.analyze_exception(exc_val, (), {})
         return False
 
+    def analyze_exception(self, e, args, kwargs):
+        if isinstance(e, self.exc_types):
+            format_dict = {'args': args,
+                           'kwargs': kwargs}
+            if self.locals is not None:
+                format_dict.update(self.locals)
+            format_dict['e'] = e
+            self.logger.log(self.severity, self.format_string.format(**format_dict),
+                            exc_info=e)
+
+        raise e
+
     def __call__(self, fun):
-        @wraps(fun)
-        def inner(*args, **kwargs):
-            try:
-                return fun(*args, **kwargs)
-            except Exception as e:
-                if isinstance(e, self.exc_types):
-                    format_dict = {'args': args,
-                                   'kwargs': kwargs}
-                    if self.locals is not None:
-                        format_dict.update(self.locals)
-                    format_dict['e'] = e
-                    self.logger.log(self.severity, self.format_string.format(format_dict),
-                                    exc_info=e)
-                raise e
-        return inner
+        if inspect.isgeneratorfunction(fun):
+            @wraps(fun)
+            def inner(*args, **kwargs):
+                try:
+                    yield from fun(*args, **kwargs)
+                except Exception as e:
+                    self.analyze_exception(e, args, kwargs)
+            return inner
+        else:
+            @wraps(fun)
+            def inner(*args, **kwargs):
+                try:
+                    return fun(*args, **kwargs)
+                except Exception as e:
+                    self.analyze_exception(e, args, kwargs)
+            return inner
 
 
+# noinspection PyPep8Naming
 class rethrow_as:
     """
     Transform some exceptions into others.
@@ -177,7 +182,20 @@ class rethrow_as:
                         raise to(self.exception_preprocessor(exc_val))
 
 
-def catch_exception(exc_class: tp.Union[ExcType, tp.Tuple[ExcType]],
+def raises_exception(exc_class: tp.Union[ExcType, tp.Tuple[ExcType, ...]],
+                     clb: tp.Callable[[], None]):
+    """
+    Does the callable raise a given exception?
+    """
+    try:
+        clb()
+    except exc_class:
+        return True
+    else:
+        return False
+
+
+def catch_exception(exc_class: tp.Union[ExcType, tp.Tuple[ExcType, ...]],
                     clb: tp.Callable[[], T],
                     return_instead: tp.Optional[T] = None,
                     return_value_on_no_exception: bool = False) -> tp.Union[Exception, T]:
