@@ -1,6 +1,4 @@
-import logging
-
-from satella.coding import merge_dicts
+from satella.coding.algos import merge_dicts
 from satella.exceptions import ConfigurationError
 from .base import BaseSource
 
@@ -8,8 +6,6 @@ __all__ = [
     'AlternativeSource', 'OptionalSource', 'MergingSource'
 ]
 
-logger = logging.getLogger(__name__)
-
 
 class AlternativeSource(BaseSource):
     """
@@ -22,7 +18,7 @@ class AlternativeSource(BaseSource):
         super().__init__()
         self.sources = sources      # type: tp.List[BaseSource]
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return 'AlternativeSource(%s)' % (repr(self.sources),)
 
     def provide(self) -> dict:
@@ -54,30 +50,42 @@ class OptionalSource(AlternativeSource):
     def __init__(self, source: BaseSource):
         super().__init__(source, BaseSource())
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return 'OptionalSource(%s)' % (repr(self.sources[0], ))
 
 
 class MergingSource(BaseSource):
     """
-    Source that merges configuration from a bunch of sources
+    Source that merges configuration from a bunch of sources. The configuration has to be a
+    dictionary!!
+
+    :param sources: Sources to examine. Source later in queue will override earlier's entries, so
+        take care.
+    :param on_fail: how to behave when a source fails
+    :param fail_if_no_sources_are_correct: even if on_fail == MergingSource.SILENT,
+        if all sources fail, this will fail as well. Of course this makes sense only if on_fail ==
+        MergingSource.SILENT
     """
 
     RAISE = 0  # Raise ConfigurationError if one of sources fails
     SILENT = 1  # Silently continue loading from next files if one fails
-    __slots__ = ('sources', 'on_fail')
+    __slots__ = ('sources', 'on_fail', 'fail_if_no_sources_are_correct')
 
-    def __init__(self, *sources: BaseSource, on_fail: int = RAISE):
+    def __init__(self, *sources: BaseSource, on_fail: int = RAISE,
+                 fail_if_no_sources_are_correct: bool = True):
         super().__init__()
         self.sources = sources
         self.on_fail = on_fail
+        self.fail_if_no_sources_are_correct = fail_if_no_sources_are_correct
 
     def provide(self) -> dict:
         cfg = {}
+        correct_sources = 0
 
         for source in self.sources:
             try:
                 p = source.provide()
+                correct_sources += 1
             except ConfigurationError as e:
                 if self.on_fail == MergingSource.RAISE:
                     raise e
@@ -89,7 +97,10 @@ class MergingSource(BaseSource):
             cfg = merge_dicts(cfg, p)
             assert isinstance(cfg, dict), 'what merge_dicts returned wasn''t a dict'
 
+        if correct_sources == 0 and self.sources and self.fail_if_no_sources_are_correct:
+            raise ConfigurationError('No source was able to load the configuration')
+
         return cfg
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return '<MergingSource %s>' % (repr(self.sources),)
