@@ -13,6 +13,7 @@ class MeasurableMixin:
     """
     Add a .measure() method, useful for HistogramMetric and SummaryMetric
     """
+    __slots__ = ()
 
     def measure_future(self, future: Future, logging_level: MetricLevel = MetricLevel.RUNTIME,
                        value_getter: tp.Callable[[], float] = time.monotonic, **labels):
@@ -32,8 +33,7 @@ class MeasurableMixin:
         future.old_value = value_getter()
 
         def on_future_done(fut: Future):
-            elapsed = value_getter() - future.old_value
-            self.handle(logging_level, elapsed, **labels)
+            self.handle(logging_level, value_getter() - fut.old_value, **labels)
 
         future.add_done_callback(on_future_done)
 
@@ -53,7 +53,7 @@ class MeasurableMixin:
         >>> def measure_my_execution(args):
         >>>     ...
 
-        If wrapped around generator, it will time it from the first element to the last,
+        If wrapped around p_gen, it will time it from the first element to the last,
         so beware that it will depend on the speed of the consumer.
 
         It also can be used as a context manager:
